@@ -22,6 +22,8 @@
 
 #include "eventslistproperty.h"
 
+#include "config-ksirk.h"
+
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgame/kgame.h>
 #include <libkdegamesprivate/kgame/kplayer.h>
@@ -135,6 +137,8 @@ class GameAutomaton : public KGame
 {
 Q_OBJECT
     
+    friend class GameSequence;
+
 public:
   /**
     * This hackish member is here to allow AIs to run only when goals have been
@@ -176,7 +180,9 @@ public:
   enum NetworkGameType {
     None,
     Socket,
+#if HAVE_JABBER_SUPPORT
     Jabber
+#endif
   };
   
   GameAutomaton();
@@ -234,7 +240,7 @@ public:
     * @param unused
     * @return the player whose turn it will be
     */
-  KPlayer* nextPlayer(KPlayer *last,bool /*exclusive*/) override;
+  KPlayer* doNextPlayer(KPlayer *last,bool /*exclusive*/);
   
   /** 
     * Retrives the number of player playing from the network.
@@ -389,7 +395,9 @@ public:
 
   inline int port() const {return m_port;}
 
+#if HAVE_JABBER_SUPPORT
   void askForJabberGames();
+#endif
 
   bool startingGame() const;
 
@@ -398,7 +406,9 @@ public:
 
   inline NetworkGameType networkGameType() {return m_netGameType;}
 
+#if HAVE_JABBER_SUPPORT
   bool joinJabberGame(const QString& nick);
+#endif
 
   void removeAllPlayers();
   // Bug 308527.
@@ -409,10 +419,12 @@ public:
   bool connectToServ();
 
   void checkGoal(Player* player = nullptr);
-  
+
+#if HAVE_JABBER_SUPPORT
 Q_SIGNALS:
   void newJabberGame(const QString&, int, const QString&);
-    
+#endif
+
 public Q_SLOTS:
   /** Reacts to the current state eventualy processing one queued event */
   GameState run();
