@@ -86,23 +86,13 @@ QDateTime stamp2TS(const QString &ts)
 {
 	if(ts.length() != 17)
 		return QDateTime();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-	int year  = ts.midRef(0,4).toInt();
-	int month = ts.midRef(4,2).toInt();
-	int day   = ts.midRef(6,2).toInt();
+	int year  = QStringView(ts).mid(0,4).toInt();
+	int month = QStringView(ts).mid(4,2).toInt();
+	int day   = QStringView(ts).mid(6,2).toInt();
 
-	int hour  = ts.midRef(9,2).toInt();
-	int min   = ts.midRef(12,2).toInt();
-	int sec   = ts.midRef(15,2).toInt();
-#else
-    int year  = QStringView(ts).mid(0,4).toInt();
-    int month = QStringView(ts).mid(4,2).toInt();
-    int day   = QStringView(ts).mid(6,2).toInt();
-
-    int hour  = QStringView(ts).mid(9,2).toInt();
-    int min   = QStringView(ts).mid(12,2).toInt();
-    int sec   = QStringView(ts).mid(15,2).toInt();
-#endif
+	int hour  = QStringView(ts).mid(9,2).toInt();
+	int min   = QStringView(ts).mid(12,2).toInt();
+	int sec   = QStringView(ts).mid(15,2).toInt();
 
 	QDate xd;
 	xd.setDate(year, month, day);
