@@ -22,6 +22,7 @@ This is the standard main function of a KDE application simplified for KsirK
 #include "kgamewin.h"
 #include "GameLogic/gameautomaton.h"
 #include <KAboutData>
+#include <KDBusService>
 #include <KCrash>
 #include "ksirk_debug.h"
 #include <QApplication>
@@ -35,7 +36,7 @@ int main(int argc, char *argv[])
 
   QApplication app(argc, argv);
 
-  KLocalizedString::setApplicationDomain("ksirk");
+  KLocalizedString::setApplicationDomain(QByteArrayLiteral("ksirk"));
 
   KAboutData aboutData(QStringLiteral("ksirk"),
                        i18n("KsirK"),
@@ -62,6 +63,8 @@ int main(int argc, char *argv[])
   parser.process(app);
   aboutData.processCommandLine(&parser);
 
+  KDBusService service;
+
   if (app.isSessionRestored())
   {
       kRestoreMainWindows<Ksirk::KGameWindow>();
