@@ -27,7 +27,6 @@
 // include files for Qt
 
 #include <QPointF>
-#include <QPixmap>
 #include <QLabel>
 #include <QPushButton>
 #include <QStackedWidget>
@@ -45,7 +44,6 @@
 class QAction;
 class KRecentFilesAction;
 
-class QGraphicsScene;
 class QGraphicsView;
 class QListWidgetItem;
 class QGraphicsPixmapItem;
@@ -57,15 +55,11 @@ class KsirkGoalDefinitionWidget;
 class KsirkSpritesDefinitionWidget;
 class KsirkNationalityDefinitionWidget;
 
-namespace Phonon
-{
-  class MediaObject;
-}
-
 namespace KsirkSkinEditor
 {
   class PixmapItem;
   class Goal;
+  class Scene;
   
 /**
   * This is the main window.
@@ -138,7 +132,7 @@ private Q_SLOTS:
   void slotItemPressed(QGraphicsItem*, const QPointF&);
   void slotItemPlaced(QGraphicsItem*, const QPointF&);
   
-  void slotOpenSkin(const QString& dir = QString());
+  void slotOpenSkin();
   void slotSaveSkin();
 
   void slotURLSelected(const QUrl&);
@@ -233,6 +227,7 @@ private Q_SLOTS:
 private:
   void initSpritesButtonsWith(const Country* country);
     
+  void openSkin(const QString& skinDir);
   void initContinentWidgetWith(Continent* continent);
   void initGoalWidgetWith(Goal* continent);
   void initNationalityWidgetWith(Nationality* nationality);
@@ -241,18 +236,13 @@ private:
   Country* currentCountry();
   void createPixmapFor(Country* country, SpriteType type);
 
-  /**
-    * Audio player object: play all the sounds of the game.
-    */
-  Phonon::MediaObject* m_audioPlayer;
-
   // the current saved game file name
   QString m_fileName;
 
   QAction * m_saveGameAction;
 
   QGraphicsView* m_mapView;
-  QGraphicsScene* m_mapScene;
+  Scene* m_mapScene;
   
   SpriteType m_selectedSprite;
 
